# Motor

O OpenMV possui portas IO e pode acionar vários motores.

## motor de passo

### O que é um motor de passo

O motor de passo é um motor de controlo de malha aberta que converte sinais de
impulsos elétricos em deslocamento angular ou deslocamento linear.

Como impressoras 3D e braços robóticos.

### Placa de driver de motor de passo

Muitos chips e módulos podem controlar motores de passo.

Simplificando, a direção é controlada por dir. Se for dado um impulso ao passo,
o motor move-se um passo.

![](/assets/06-07-001.jpg)

### Conectar

![](/assets/06-07-002.jpg)

## Instalar módulo

[O código do módulo está neste
link](http://book.openmv.cc/module/write-module-motor.html)

Guarde o código desta classe como um ficheiro stepper.py e coloque-o no
directório raiz do OpenMV.

## código

```python
# 步进电机控制 - By: 小智智- 周日 4月 2 2017

from pyb import Pin

from stepper import Stepper

import time

step_pin = Pin('P0')
dir_pin = Pin('P1')

my_stepper = Stepper(step_pin,dir_pin)

print("relative angle move test begin:", my_stepper.read_pos())
my_stepper.rel_angle(180)#相对角度控制
print("relative angle move test end:", my_stepper.read_pos())

time.sleep_ms(1000)

print("steps angle move test end:", my_stepper.read_pos())
my_stepper.steps(-400)#步进脉冲控制
print("steps angle move test end:", my_stepper.read_pos())

time.sleep_ms(1000)

print("absolute angle move test begin:", my_stepper.read_pos())
my_stepper.abs_angle(0)#绝对角度控制
print("absolute angle move test end:", my_stepper.read_pos())

time.sleep_ms(1000)
```

## Motor CC

#### Tutorial 26 – A versão de extensão do motor controla o motor CC: [https://singtown.com/video](https://singtown.com/video)

### O que é um motor de corrente contínua

A velocidade de um motor de corrente contínua é diretamente proporcional à
tensão.

### Placa de condutor

Muitas placas de driver podem acionar motores DC, aqui usamos TB6612FNG, ponte H
dupla.

![](/assets/06-07-003.jpg)

### Conectar

![](/assets/06-07-004.jpg)

### código

```python
待添加
```

## engrenagem de direção

O OpenMV2 possui dois pinos servo, P7 e P8

O OpenMV3 possui três pinos servo, P7, P8, P9

### Conectar

![](/assets/06-07-005.jpg)

### Verifique a fonte de alimentação

O servo é um dispositivo de alta corrente e deve utilizar uma fonte de
alimentação externa (fonte de alimentação regulada, bateria de lítio...)！

### código

```python
# Servo Control Example
#
# This example shows how to use your OpenMV Cam to control servos.

import time
from pyb import Servo

s1 = Servo(1) # P7
s2 = Servo(2) # P8
#s3 = Servo(3) # P9 Only for OpenMV3 M7
while(True):
    for i in range(-90,90):
        s1.angle(i)
        s2.angle(i)
        time.sleep_ms(10)
    for i in range(90,-90):
        s1.angle(i)
        s2.angle(i)
        time.sleep_ms(10)
```

## PCA9685 liga vários servos

Link do bebé:
[https://singtown.com/product/49277](https://singtown.com/product/49277)

#### Tutorial em vídeo 25 - pca9685 controla vários servos: [https://singtown.com/learn/50057/](https://singtown.com/learn/50057/)



O módulo PCA9685, utilizando apenas 2 pinos (protocolo I2C), pode controlar 16
canais PWM, ou seja, 16 servos ou 16 luzes LED. Pode até ligar 62 módulos e
ainda assim usar apenas 2 pinos para controlar 992 PWMs!

Conectar

![](/assets/06-07-006-01.jpg)

código

![](/assets/06-07-007.jpg)

Clique para executar

